GetBlockHeightConfig class

Annotations
  • @JsonSerializable.new(createFactory: false, includeIfNull: false, explicitToJson: true)

Constructors

GetBlockHeightConfig({Commitment? commitment, num? minContextSlot})

Properties

commitment → Commitment?
final
hashCode → int
The hash code for this object.
no setterinherited
minContextSlot → num?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited