SendTransactionConfig class

Annotations
  • @JsonSerializable.new(createFactory: false, includeIfNull: false, explicitToJson: true)

Constructors

SendTransactionConfig({Encoding encoding = Encoding.base64, Commitment? preflightCommitment = Commitment.finalized, bool? skipPreflight = false, int? maxRetries, num? minContextSlot})

Properties

encoding → Encoding
final
hashCode → int
The hash code for this object.
no setterinherited
maxRetries → int?
final
minContextSlot → num?
final
preflightCommitment → Commitment?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipPreflight → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited