SolanaTransaction class

Constructors

SolanaTransaction({required List<Instruction> instructions, String? recentBlockHash, List<String>? signatures = const []})

Properties

hashCode → int
The hash code for this object.
no setterinherited
instructions ↔ List<Instruction>
getter/setter pair
recentBlockHash ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatures ↔ List<String>?
getter/setter pair

Methods

copyWith({String? recentBlockHash, List<Instruction>? instructions, List<String>? signatures}) → SolanaTransaction
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited