SolwaveTransaction class

Constructors

SolwaveTransaction({required TransactionPayload data, SolwaveTransactionStatus? status, SimulationType? type})

Properties

data ↔ TransactionPayload
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isTransferInstruction → dynamic
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ SolwaveTransactionStatus?
getter/setter pair
type ↔ SimulationType?
getter/setter pair

Methods

copyWith({TransactionPayload? data, SolwaveTransactionStatus? status, SimulationType? type}) → SolwaveTransaction
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited