TransactionPayload class

Constructors

TransactionPayload({double fees = 0.0, String? from, int? lamports, String? to, required SolanaTransaction transaction})

Properties

fees ↔ double
getter/setter pair
from ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lamports ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to ↔ String?
getter/setter pair
transaction ↔ SolanaTransaction
getter/setter pair

Methods

copyWith({double? fees, String? from, int? lamports, String? to, SolanaTransaction? transaction}) → TransactionPayload
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited